@@ -174,7 +174,7 @@ class InnocuousAPI:
             return json.loads(r.text)['data'][0]
         return None
 
-    def list_experiment(self):
+    def list_experiments(self):
         """List all experiment 
         Returns:
             {
@@ -241,9 +241,15 @@ class InnocuousAPI:
         self._get_jwt_token()
         url = self.host + f"/api/experiment/result/{id}"
         r = self.session.get(url, headers=self.headers)
-        if r.status_code == 200 and json.loads(r.text)['code'] == 0:
-            return json.loads(r.text)['data']
-        return None
+        self.log.info(json.loads(r.text))
+        self.log.info(r.status_code)
+        self.log.info(json.loads(r.text)['result'])
+        if r.status_code == 200 and json.loads(r.text)['result'] == 'ok':
+            self.log.info('correct request')
+            return json.loads(r.text)
+        else:
+            self.log.info('incorrect request, returning None')
+            return None
 
     def kill_experiment(self, id):
         """Kill experiment
@@ -309,7 +315,7 @@ class InnocuousAPI:
             return json.loads(r.text)['data'][0]
         return None
     
-    def list_endpoint(self):
+    def list_endpoints(self):
         """List all endpoint 
         Returns:
             {
@@ -373,7 +379,7 @@ class InnocuousAPI:
             return r.json()
         return False
 
-    def call_endpoint_continous_learning(self, id, dataset):
+    def call_endpoint_continuous_learning(self, id, dataset):
         """Call endpoint api of continous_learnin
         Args:
             id: Id of endpoint
